@@ -163,7 +163,7 @@ class MyWhatify:
                          ' and skip if exist= ' + str(skip_if_exists)):
             source_id = -1
             try:
-                if not data_file:
+                if data_file is None:
                     data_file = cls.get_data_file_s3(file_name=data_name)
                 source_id = my_toolkit.Datasource.create_from_dataframe(df=data_file, data_source_name=data_name,
                                                                         wait=wait, skip_if_exists=skip_if_exists,
